/*  Gringotts - a small utility to safe-keep sensitive data
 *  (c) 2002, Germano Rizzo <mano@pluto.linux.it>
 *
 *  grg_popt.c - commandline argument parsing via POPT
 *  Author: Germano Rizzo
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <popt.h>

#include <glib.h>

#include "grg_defs.h"
#include "gringotts.h"

void grg_parse_argv (gint argc, gchar *argv[], gchar **filename, gboolean *rootCheck){
	poptContext optCon;
	gint help=0;
	
	struct poptOption optionsTable[] = {
		 {"help", 'h', POPT_ARG_NONE, &help, 1, _("shows the help"), NULL},
		 {"input-file", 'f', POPT_ARG_STRING, filename, 0, _("specify the input file to open"), _("FILE")},
#ifndef ROOT_FILTER
		 {"allow-root", 's', POPT_ARG_NONE, rootCheck, 1, _("allows usage as root -- DANGEROUS"), NULL},
#endif
		 {NULL, 0, 0, NULL, 0}
	};

	*filename = NULL;
	*rootCheck = FALSE;

	optCon = poptGetContext(NULL, argc, (const char **)argv, optionsTable, 0);
	
	while(poptGetNextOpt(optCon) >= 0);

	if (help) {
		poptPrintHelp(optCon, stdout, 0);
		meta_quit ();
    }
	
	poptFreeContext(optCon);
}
